@@ -1,5 +1,5 @@
-from .JPFixture import JPPreRun, JPPostRun
+from .JPSetup import JPSetup, JPTeardown
 from .JPTest import JPTest
 from .JPTestComparison import JPTestComparison
 from .JPTestGet import JPTestGet
-from .notebook import Notebook
+from .notebook import Notebook, NotebookReference
